@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2015 The Music Player Daemon Project
+   (c) 2003-2017 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -39,7 +39,7 @@
 #ifndef MPD_OUTPUT_H
 #define MPD_OUTPUT_H
 
-#include <mpd/compiler.h>
+#include "compiler.h"
 
 #include <stdbool.h>
 
@@ -178,6 +178,8 @@ mpd_run_disable_output(struct mpd_connection *connection, unsigned output_id);
  * @param output_id an identifier for the output device (see
  * mpd_recv_output())
  * @return true on success
+ *
+ * @since libmpdclient 2.9
  */
 bool
 mpd_send_toggle_output(struct mpd_connection *connection, unsigned output_id);
@@ -189,6 +191,8 @@ mpd_send_toggle_output(struct mpd_connection *connection, unsigned output_id);
  * @param output_id an identifier for the output device (see
  * mpd_recv_output())
  * @return true on success
+ *
+ * @since libmpdclient 2.9
  */
 bool
 mpd_run_toggle_output(struct mpd_connection *connection, unsigned output_id);
