@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2010 The Music Player Daemon Project
+   (c) 2003-2017 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,8 @@
 #ifndef MPD_QUEUE_H
 #define MPD_QUEUE_H
 
-#include <mpd/compiler.h>
+#include "compiler.h"
+#include "tag.h"
 
 #include <stdbool.h>
 
@@ -59,8 +60,11 @@ mpd_send_list_queue_meta(struct mpd_connection *connection);
  *
  * @param connection the connection to MPD
  * @param start the start position of the range (including)
- * @param end the end position of the range (excluding)
+ * @param end the end position of the range (excluding); the special
+ * value "(unsigned)-1" makes the end of the range open
  * @return true on success, false on error
+ *
+ * @since libmpdclient 2.8 added support for "(unsigned)-1"
  */
 bool
 mpd_send_list_queue_range_meta(struct mpd_connection *connection,
@@ -120,6 +124,23 @@ bool
 mpd_send_queue_changes_meta(struct mpd_connection *connection,
 			    unsigned version);
 
+/**
+ * Same as mpd_send_queue_changes_meta(), but limit the result to a
+ * range.
+ *
+ * @param connection the connection to MPD
+ * @param start the start position of the range (including)
+ * @param end the end position of the range (excluding); the special
+ * value "(unsigned)-1" makes the end of the range open
+ * @return true on success, false on error
+ *
+ * @since libmpdclient 2.12
+ */
+bool
+mpd_send_queue_changes_meta_range(struct mpd_connection *connection,
+				  unsigned version,
+				  unsigned start, unsigned end);
+
 /**
  * A more bandwidth efficient version of the
  * mpd_send_queue_changes_meta().  It only returns the position and id
@@ -133,6 +154,23 @@ bool
 mpd_send_queue_changes_brief(struct mpd_connection *connection,
 			     unsigned version);
 
+/**
+ * Same as mpd_send_queue_changes_brief(), but limit the result to a
+ * range.
+ *
+ * @param connection the connection to MPD
+ * @param start the start position of the range (including)
+ * @param end the end position of the range (excluding); the special
+ * value "(unsigned)-1" makes the end of the range open
+ * @return true on success, false on error
+ *
+ * @since libmpdclient 2.12
+ */
+bool
+mpd_send_queue_changes_brief_range(struct mpd_connection *connection,
+				   unsigned version,
+				   unsigned start, unsigned end);
+
 /**
  * Receives a response element of mpd_send_queue_changes_brief().
  *
@@ -233,8 +271,11 @@ mpd_run_delete(struct mpd_connection *connection, unsigned pos);
  *
  * @param connection the connection to MPD
  * @param start the start position of the range (including)
- * @param end the end position of the range (excluding)
+ * @param end the end position of the range (excluding); the special
+ * value "(unsigned)-1" makes the end of the range open
  * @return true on success, false on error
+ *
+ * @since libmpdclient 2.8 added support for "(unsigned)-1"
  */
 bool
 mpd_send_delete_range(struct mpd_connection *connection,
@@ -245,8 +286,11 @@ mpd_send_delete_range(struct mpd_connection *connection,
  *
  * @param connection the connection to MPD
  * @param start the start position of the range (including)
- * @param end the end position of the range (excluding)
+ * @param end the end position of the range (excluding); the special
+ * value "(unsigned)-1" makes the end of the range open
  * @return true on success, false on error
+ *
+ * @since libmpdclient 2.8 added support for "(unsigned)-1"
  */
 bool
 mpd_run_delete_range(struct mpd_connection *connection,
@@ -292,7 +336,10 @@ mpd_run_shuffle(struct mpd_connection *connection);
  *
  * @param connection the connection to MPD
  * @param start the start position of the range (including)
- * @param end the end position of the range (excluding)
+ * @param end the end position of the range (excluding); the special
+ * value "(unsigned)-1" makes the end of the range open
+ *
+ * @since libmpdclient 2.8 added support for "(unsigned)-1"
  */
 bool
 mpd_send_shuffle_range(struct mpd_connection *connection, unsigned start, unsigned end);
@@ -302,7 +349,10 @@ mpd_send_shuffle_range(struct mpd_connection *connection, unsigned start, unsign
  *
  * @param connection the connection to MPD
  * @param start the start position of the range (including)
- * @param end the end position of the range (excluding)
+ * @param end the end position of the range (excluding); the special
+ * value "(unsigned)-1" makes the end of the range open
+ *
+ * @since libmpdclient 2.8 added support for "(unsigned)-1"
  */
 bool
 mpd_run_shuffle_range(struct mpd_connection *connection,
@@ -369,9 +419,12 @@ mpd_run_move_id(struct mpd_connection *connection, unsigned from, unsigned to);
  *
  * @param connection the connection to MPD
  * @param start the start position of the range (including)
- * @param end the end position of the range (excluding)
+ * @param end the end position of the range (excluding); the special
+ * value "(unsigned)-1" makes the end of the range open
  * @param to the new position of the song range
  * @return true on success, false on error
+ *
+ * @since libmpdclient 2.8 added support for "(unsigned)-1"
  */
 bool
 mpd_send_move_range(struct mpd_connection *connection,
@@ -382,9 +435,12 @@ mpd_send_move_range(struct mpd_connection *connection,
  *
  * @param connection the connection to MPD
  * @param start the start position of the range (including)
- * @param end the end position of the range (excluding)
+ * @param end the end position of the range (excluding); the special
+ * value "(unsigned)-1" makes the end of the range open
  * @param to the new position of the song range
  * @return true on success, false on error
+ *
+ * @since libmpdclient 2.8 added support for "(unsigned)-1"
  */
 bool
 mpd_run_move_range(struct mpd_connection *connection,
@@ -430,12 +486,90 @@ mpd_send_swap_id(struct mpd_connection *connection, unsigned id1, unsigned id2);
 bool
 mpd_run_swap_id(struct mpd_connection *connection, unsigned id1, unsigned id2);
 
+/**
+ * Adds a tag to the specified song (command "addtagid").
+ *
+ * @param connection the connection to MPD
+ * @param id the id of the song
+ * @param tag the tag to be added
+ * @param value the tag value
+ *
+ * @since libmpdclient 2.12, MPD 0.19
+ */
+bool
+mpd_send_add_tag_id(struct mpd_connection *connection, unsigned id,
+		    enum mpd_tag_type tag, const char *value);
+
+/**
+ * Shortcut for mpd_send_add_tag_id() and mpd_response_finish().
+ *
+ * @param connection the connection to MPD
+ * @param id the id of the song
+ * @param tag the tag to be added
+ * @param value the tag value
+ *
+ * @since libmpdclient 2.12, MPD 0.19
+ */
+bool
+mpd_run_add_tag_id(struct mpd_connection *connection, unsigned id,
+		   enum mpd_tag_type tag, const char *value);
+
+/**
+ * Remove a tag from the specified song (command "cleartagid").
+ *
+ * @param connection the connection to MPD
+ * @param id the id of the song
+ * @param tag the tag to be cleared
+ *
+ * @since libmpdclient 2.12, MPD 0.19
+ */
+bool
+mpd_send_clear_tag_id(struct mpd_connection *connection, unsigned id,
+		      enum mpd_tag_type tag);
+
+/**
+ * Shortcut for mpd_send_clear_tag_id() and mpd_response_finish().
+ *
+ * @param connection the connection to MPD
+ * @param id the id of the song
+ * @param tag the tag to be cleared
+ *
+ * @since libmpdclient 2.12, MPD 0.19
+ */
+bool
+mpd_run_clear_tag_id(struct mpd_connection *connection, unsigned id,
+		     enum mpd_tag_type tag);
+
+/**
+ * Remove all tags from the specified song (command "cleartagid").
+ *
+ * @param connection the connection to MPD
+ * @param id the id of the song
+ *
+ * @since libmpdclient 2.12, MPD 0.19
+ */
+bool
+mpd_send_clear_all_tags_id(struct mpd_connection *connection, unsigned id);
+
+/**
+ * Shortcut for mpd_send_clear_all_tags_id() and mpd_response_finish().
+ *
+ * @param connection the connection to MPD
+ * @param id the id of the song
+ *
+ * @since libmpdclient 2.12, MPD 0.19
+ */
+bool
+mpd_run_clear_all_tags_id(struct mpd_connection *connection, unsigned id);
+
 /**
  * Change the priority of the specified song.
  *
  * @param connection the connection to MPD
  * @param priority a number between 0 and 255
  * @param position the position of the song
+ *
+ * @since libmpdclient 2.6
  */
 bool
 mpd_send_prio(struct mpd_connection *connection, int priority,
@@ -446,8 +580,9 @@ mpd_send_prio(struct mpd_connection *connection, int priority,
  *
  * @param connection the connection to MPD
  * @param priority a number between 0 and 255
- * @param start the start position of the range (including)
- * @param end the end position of the range (excluding)
+ * @param position the position of the song
+ *
+ * @since libmpdclient 2.6
  */
 bool
 mpd_run_prio(struct mpd_connection *connection, int priority,
@@ -458,7 +593,12 @@ mpd_run_prio(struct mpd_connection *connection, int priority,
  *
  * @param connection the connection to MPD
  * @param priority a number between 0 and 255
- * @param position the position of the song
+ * @param start the start position of the range (including)
+ * @param end the end position of the range (excluding); the special
+ * value "(unsigned)-1" makes the end of the range open
+ *
+ * @since libmpdclient 2.6
+ * @since libmpdclient 2.8 added support for "(unsigned)-1"
  */
 bool
 mpd_send_prio_range(struct mpd_connection *connection, int priority,
@@ -469,7 +609,12 @@ mpd_send_prio_range(struct mpd_connection *connection, int priority,
  *
  * @param connection the connection to MPD
  * @param priority a number between 0 and 255
- * @param position the position of the song
+ * @param start the start position of the range (including)
+ * @param end the end position of the range (excluding); the special
+ * value "(unsigned)-1" makes the end of the range open
+ *
+ * @since libmpdclient 2.6
+ * @since libmpdclient 2.8 added support for "(unsigned)-1"
  */
 bool
 mpd_run_prio_range(struct mpd_connection *connection, int priority,
@@ -481,6 +626,8 @@ mpd_run_prio_range(struct mpd_connection *connection, int priority,
  * @param connection the connection to MPD
  * @param priority a number between 0 and 255
  * @param id the id of the song
+ *
+ * @since libmpdclient 2.6
  */
 bool
 mpd_send_prio_id(struct mpd_connection *connection, int priority,
@@ -492,6 +639,8 @@ mpd_send_prio_id(struct mpd_connection *connection, int priority,
  * @param connection the connection to MPD
  * @param priority a number between 0 and 255
  * @param id the id of the song
+ *
+ * @since libmpdclient 2.6
  */
 bool
 mpd_run_prio_id(struct mpd_connection *connection, int priority,
