@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2015 The Music Player Daemon Project
+   (c) 2003-2017 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,7 @@
 #ifndef MPD_RECV_H
 #define MPD_RECV_H
 
-#include <mpd/compiler.h>
+#include "compiler.h"
 
 struct mpd_pair;
 struct mpd_connection;
